@@ -1,12 +1,12 @@
 from typing import Any, Dict
 
 from setuptools_cpp import CMakeExtension, ExtensionBuilder
+# from cmake_build_extension import CMakeExtension, BuildExtension
 
 ext_modules = [
-    CMakeExtension(f"libiri", sourcedir="src/iricore"),
+    CMakeExtension("iricore", sourcedir="src/iricore"),
 ]
 
-
 def build(setup_kwargs: Dict[str, Any]) -> None:
     setup_kwargs.update(
         {
